Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(972)

Unified Diff: content/public/browser/content_browser_client.h

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/browser_context.h ('k') | content/public/browser/speech_input_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/content_browser_client.h
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h
index 19eb3b308dea7ee72d2725d581d1df7f2a268b4d..cca6ae20889cb74c8a3b7a577f9b2e702943d64c 100644
--- a/content/public/browser/content_browser_client.h
+++ b/content/public/browser/content_browser_client.h
@@ -26,6 +26,18 @@ class ResourceDispatcherHost;
class SkBitmap;
struct WebPreferences;
+namespace content {
+class AccessTokenStore;
+class BrowserMainParts;
+class RenderProcessHost;
+class SiteInstance;
+class SpeechRecognitionManagerDelegate;
+class WebContents;
+class WebContentsView;
+struct MainFunctionParams;
+struct ShowDesktopNotificationHostMsgParams;
+}
+
namespace crypto {
class CryptoModuleBlockingPasswordDelegate;
}
@@ -322,9 +334,10 @@ class ContentBrowserClient {
// This is when it can optionally add a delegate or ResourceQueueDelegates.
virtual void ResourceDispatcherHostCreated() = 0;
- // Allows the embedder to return a delegate for the SpeechInputManager. The
- // delegate will be owned by the manager. It's valid to return NULL.
- virtual SpeechInputManagerDelegate* GetSpeechInputManagerDelegate() = 0;
+ // Allows the embedder to return a delegate for the SpeechRecognitionManager.
+ // The delegate will be owned by the manager. It's valid to return NULL.
+ virtual SpeechRecognitionManagerDelegate*
+ GetSpeechRecognitionManagerDelegate() = 0;
// Getters for common objects.
virtual ui::Clipboard* GetClipboard() = 0;
« no previous file with comments | « content/public/browser/browser_context.h ('k') | content/public/browser/speech_input_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698